summaryrefslogtreecommitdiffstats
path: root/catalog-be/sdc-backend-init
diff options
context:
space:
mode:
Diffstat (limited to 'catalog-be/sdc-backend-init')
-rw-r--r--catalog-be/sdc-backend-init/chef-repo/cookbooks/sdc-catalog-be-setup/recipes/3_import_Normatives.rb28
1 files changed, 6 insertions, 22 deletions
diff --git a/catalog-be/sdc-backend-init/chef-repo/cookbooks/sdc-catalog-be-setup/recipes/3_import_Normatives.rb b/catalog-be/sdc-backend-init/chef-repo/cookbooks/sdc-catalog-be-setup/recipes/3_import_Normatives.rb
index 79f880b146..e9e44c0df9 100644
--- a/catalog-be/sdc-backend-init/chef-repo/cookbooks/sdc-catalog-be-setup/recipes/3_import_Normatives.rb
+++ b/catalog-be/sdc-backend-init/chef-repo/cookbooks/sdc-catalog-be-setup/recipes/3_import_Normatives.rb
@@ -22,29 +22,13 @@ bash "executing-import_Normatives" do
tar -xvf normatives.tar.gz
# executing the normatives
- # add --debug to the importNormativeAll.py arguments to enable debug
-
- check_normative="/tmp/check_normative.out"
- status_code=$(curl -k -s -o ${check_normative} -w "%{http_code}\\n" -X GET -H 'Content-Type: application/json;charset=UTF-8' -H 'USER_ID: jh0003' -H 'X-ECOMP-RequestID: cbe744a0-037b-458f-aab5-df6e543c4090' "#{protocol}://#{be_ip}:#{be_port}/sdc2/rest/v1/screen")
- if [ "$status_code" != 200 ] ; then
- exit "$status_code"
- fi
-
- #curl -s -X GET -H "Content-Type: application/json;charset=UTF-8" -H "USER_ID: jh0003" -H "X-ECOMP-RequestID: cbe744a0-037b-458f-aab5-df6e543c4090" "#{protocol}://#{be_ip}:#{be_port}/sdc2/rest/v1/screen" > ${check_normative}
-
- resources_len=`cat ${check_normative}| jq '.["resources"]|length'`
- mkdir -p /var/lib/jetty/logs
+ # add --debug to the sdcinit command to enable debug
+
+ cd /var/tmp/normatives/import/tosca
+ sdcinit #{param} > /var/lib/jetty/logs/init.log
+ rc=$?
+ if [[ $rc != 0 ]]; then exit $rc; fi
- cd /var/tmp/normatives/import/tosca/
- if [ $resources_len -eq 0 ] ; then
- sdcimportall #{param} > /var/lib/jetty/logs/importNormativeAll.log
- rc=$?
- if [[ $rc != 0 ]]; then exit $rc; fi
- else
- sdcupgradeall #{param} > /var/lib/jetty/logs/upgradeNormative.log
- rc=$?
- if [[ $rc != 0 ]]; then exit $rc; fi
- fi
EOH
returns [0]
end